Contributions by
----------------
Contributors, please add you name here! By doing this, you also state, that you
have signed the Plone Contributors Agreement [1][2]. Thanks!

- Johannes Raggam, thet
- Andreas Jung
- Lennart Regebro
- JeanMichel FRANCOIS, toutpt
- Philip Bauer, pbauer
- Róman Joost, romanofski

To be confirmed:
- Florian Sprenger <f.sprenger@4teamwork.ch>
- Franklin Kingma <franklin@fourdigits.nl>
- Giacomo Spettoli <giacomo.spettoli@gmail.com>
- Jens Klein
- Robert Niederreiter <office@squarewave.at>
- Rok Garbas <rok@garbas.si>
- Roland Fasching <roland.fasching@gmail.com>
- Sean Upton <sdupton@gmail.com>
- gogo <gogo@3b4cdb85-528f-c531-b63d-5919d5b1aa08>
- piv <piv@3b4cdb85-528f-c531-b63d-5919d5b1aa08>
- simahawk <simahawk@3b4cdb85-528f-c531-b63d-5919d5b1aa08>
- tdesvenain <thomas.desvenain@gmail.com>
- tom_gross <tom_gross@3b4cdb85-528f-c531-b63d-5919d5b1aa08>
- vincentfretin <vincentfretin@3b4cdb85-528f-c531-b63d-5919d5b1aa08>

Find out who contributed:
$ git shortlog -s -e

[1] http://plone.org/foundation/contributors-agreement/contributors-agreement-explained
[2] http://plone.org/foundation/contributors-agreement/agreement.pdf/view
